@@ -208,3 +208,23 @@ class NavSoapClient():
 
         serialized_response = serialize_object(soap_response)
         return serialized_response
+
+    def get_item_images(self, item_number):
+        """
+        Returns a base64 encoded string that represents the image for
+        a given item_number
+
+        param item_number: The item number pulled from the Integration_Item_Card service
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/MfgFunctionsWS"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.GetItemImage(itemNo=item_number)
+
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
